@@ -129,6 +129,16 @@ atk_role_get_type (void)
       { ATK_ROLE_LEVEL_BAR, "ATK_ROLE_LEVEL_BAR", "level-bar" },
       { ATK_ROLE_TITLE_BAR, "ATK_ROLE_TITLE_BAR", "title-bar" },
       { ATK_ROLE_BLOCK_QUOTE, "ATK_ROLE_BLOCK_QUOTE", "block-quote" },
+      { ATK_ROLE_AUDIO, "ATK_ROLE_AUDIO", "audio" },
+      { ATK_ROLE_VIDEO, "ATK_ROLE_VIDEO", "video" },
+      { ATK_ROLE_DEFINITION, "ATK_ROLE_DEFINITION", "definition" },
+      { ATK_ROLE_ARTICLE, "ATK_ROLE_ARTICLE", "article" },
+      { ATK_ROLE_LANDMARK, "ATK_ROLE_LANDMARK", "landmark" },
+      { ATK_ROLE_LOG, "ATK_ROLE_LOG", "log" },
+      { ATK_ROLE_MARQUEE, "ATK_ROLE_MARQUEE", "marquee" },
+      { ATK_ROLE_MATH, "ATK_ROLE_MATH", "math" },
+      { ATK_ROLE_RATING, "ATK_ROLE_RATING", "rating" },
+      { ATK_ROLE_TIMER, "ATK_ROLE_TIMER", "timer" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -235,6 +245,8 @@ atk_state_type_get_type (void)
       { ATK_STATE_DEFAULT, "ATK_STATE_DEFAULT", "default" },
       { ATK_STATE_ANIMATED, "ATK_STATE_ANIMATED", "animated" },
       { ATK_STATE_VISITED, "ATK_STATE_VISITED", "visited" },
+      { ATK_STATE_CHECKABLE, "ATK_STATE_CHECKABLE", "checkable" },
+      { ATK_STATE_HAS_POPUP, "ATK_STATE_HAS_POPUP", "has-popup" },
       { ATK_STATE_LAST_DEFINED, "ATK_STATE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
